ZMetric
=======

.. currentmodule:: pykeen.metrics.ranking

.. autoclass:: ZMetric
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~ZMetric.increasing
      ~ZMetric.supported_rank_types
      ~ZMetric.value_range

   .. rubric:: Methods Summary

   .. autosummary::

      ~ZMetric.expected_value
      ~ZMetric.get_coefficients
      ~ZMetric.variance

   .. rubric:: Attributes Documentation

   .. autoattribute:: increasing
   .. autoattribute:: supported_rank_types
   .. autoattribute:: value_range

   .. rubric:: Methods Documentation

   .. automethod:: expected_value
   .. automethod:: get_coefficients
   .. automethod:: variance
